Documentation
¶
Overview ¶
Package internal implements user facing commands for sloctl.
Index ¶
- Variables
- func Execute()
- func NewRootCmd() *cobra.Command
- func NewVersionCmd() *cobra.Command
- type ApplyCmd
- type AwsIamIdsCmd
- type ConfigCmd
- func (c *ConfigCmd) AddContextCommand() *cobra.Command
- func (c *ConfigCmd) CurrentContextCommand() *cobra.Command
- func (c *ConfigCmd) CurrentUserCommand() *cobra.Command
- func (c *ConfigCmd) DeleteContextCommand() *cobra.Command
- func (c *ConfigCmd) GetContextsCommand() *cobra.Command
- func (c *ConfigCmd) RenameContextCommand() *cobra.Command
- func (c *ConfigCmd) UseContextCommand() *cobra.Command
- type ConvertCmd
- type DeleteCmd
- type GetCmd
- type MCPCmd
- type MoveCmd
- type PlaylistConfiguration
- type ReplayCmd
- func (r *ReplayCmd) AddCancelCommand() *cobra.Command
- func (r *ReplayCmd) AddDeleteCommand() *cobra.Command
- func (r *ReplayCmd) AddListCommand() *cobra.Command
- func (r *ReplayCmd) Run(cmd *cobra.Command) error
- func (r *ReplayCmd) RunReplays(cmd *cobra.Command, replays []ReplayConfig) (failedReplays int, err error)
- type ReplayConfig
- type ReplayListItem
- type ReviewCmd
- func (r *ReviewCmd) NewSetStatusCmd() *cobra.Command
- func (r *ReviewCmd) NewSetStatusNotStartedCmd() *cobra.Command
- func (r *ReviewCmd) NewSetStatusOverdueCmd() *cobra.Command
- func (r *ReviewCmd) NewSetStatusReviewedCmd() *cobra.Command
- func (r *ReviewCmd) NewSetStatusSkippedCmd() *cobra.Command
- func (r *ReviewCmd) NewSetStatusToReviewCmd() *cobra.Command
- type RootCmd
- func (r *RootCmd) GetClient() *sdk.Client
- func (r *RootCmd) NewApplyCmd() *cobra.Command
- func (r *RootCmd) NewAwsIamIds() *cobra.Command
- func (r *RootCmd) NewConfigCmd() *cobra.Command
- func (r *RootCmd) NewConvertCmd() *cobra.Command
- func (r *RootCmd) NewDeleteCmd() *cobra.Command
- func (r *RootCmd) NewGetCmd() *cobra.Command
- func (r *RootCmd) NewMCPCmd() *cobra.Command
- func (r *RootCmd) NewMoveCmd() *cobra.Command
- func (r *RootCmd) NewReplayCmd() *cobra.Command
- func (r *RootCmd) NewReviewCmd() *cobra.Command
- type Spinner
Constants ¶
This section is empty.
Variables ¶
var ( BuildGitRevision string BuildGitBranch string BuildVersion string )
Set during build time.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func NewRootCmd ¶
NewRootCmd returns the base command when called without any subcommands
func NewVersionCmd ¶
NewVersionCmd returns cobra command version with all flags for it.
Types ¶
type AwsIamIdsCmd ¶
type AwsIamIdsCmd struct {
// contains filtered or unexported fields
}
func (*AwsIamIdsCmd) DataExport ¶
func (a *AwsIamIdsCmd) DataExport(cmd *cobra.Command) error
type ConfigCmd ¶
type ConfigCmd struct {
// contains filtered or unexported fields
}
func (*ConfigCmd) AddContextCommand ¶
func (*ConfigCmd) CurrentContextCommand ¶
func (*ConfigCmd) CurrentUserCommand ¶ added in v0.13.0
func (*ConfigCmd) DeleteContextCommand ¶
func (*ConfigCmd) GetContextsCommand ¶
func (*ConfigCmd) RenameContextCommand ¶
func (*ConfigCmd) UseContextCommand ¶ added in v0.17.0
type ConvertCmd ¶ added in v0.12.0
type ConvertCmd struct {
// contains filtered or unexported fields
}
type PlaylistConfiguration ¶ added in v0.7.0
type PlaylistConfiguration struct {
EnabledPlaylists bool `json:"enabledPlaylists"`
}
type ReplayCmd ¶
type ReplayCmd struct {
// contains filtered or unexported fields
}
func (*ReplayCmd) AddCancelCommand ¶ added in v0.13.0
AddCancelCommand returns cobra command delete, which allows to cancel running Replay.
func (*ReplayCmd) AddDeleteCommand ¶ added in v0.7.0
AddDeleteCommand returns cobra command delete, which allows to delete a queued Replay.
func (*ReplayCmd) AddListCommand ¶ added in v0.7.0
AddListCommand returns cobra command list, which allows to list all queued Replays.
func (*ReplayCmd) RunReplays ¶
type ReplayConfig ¶
type ReplayListItem ¶ added in v0.13.0
type ReplayListItem struct {
Slo string `json:"slo,omitempty"`
Project string `json:"project"`
ElapsedTime string `json:"elapsedTime,omitempty"`
RetrievedScope string `json:"retrievedScope,omitempty"`
RetrievedFrom string `json:"retrievedFrom,omitempty"`
Status string `json:"status"`
Cancellation string `json:"cancellation,omitempty"`
}
type ReviewCmd ¶ added in v0.18.0
type ReviewCmd struct {
// contains filtered or unexported fields
}
func (*ReviewCmd) NewSetStatusCmd ¶ added in v0.18.0
func (*ReviewCmd) NewSetStatusNotStartedCmd ¶ added in v0.18.0
func (*ReviewCmd) NewSetStatusOverdueCmd ¶ added in v0.18.0
func (*ReviewCmd) NewSetStatusReviewedCmd ¶ added in v0.18.0
func (*ReviewCmd) NewSetStatusSkippedCmd ¶ added in v0.18.0
func (*ReviewCmd) NewSetStatusToReviewCmd ¶ added in v0.18.0
type RootCmd ¶
type RootCmd struct {
Client *sdk.Client
Flags globalFlags
// contains filtered or unexported fields
}
func (*RootCmd) NewApplyCmd ¶
NewApplyCmd returns cobra command apply with all its flags.
func (*RootCmd) NewAwsIamIds ¶
func (*RootCmd) NewConfigCmd ¶
func (*RootCmd) NewConvertCmd ¶ added in v0.12.0
func (*RootCmd) NewDeleteCmd ¶
NewDeleteCmd returns cobra command delete with all its flags.
func (*RootCmd) NewMoveCmd ¶ added in v0.16.0
func (*RootCmd) NewReplayCmd ¶
func (*RootCmd) NewReviewCmd ¶ added in v0.18.0
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package csv provides a builder for csv data
|
Package csv provides a builder for csv data |
|
Package jq provides logic which makes it easier to interact with gojq library.
|
Package jq provides logic which makes it easier to interact with gojq library. |
|
Package printer provides utilities for printing standard structures from api in convenient formats.
|
Package printer provides utilities for printing standard structures from api in convenient formats. |