Documentation
¶
Overview ¶
Package csv provides a builder for csv data
Index ¶
Constants ¶
const ( DefaultFieldSeparator = "," DefaultRecordSeparator = "\n" FieldSeparatorFlag = "field-separator" RecordSeparatorFlag = "record-separator" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Node ¶
type Node struct {
// contains filtered or unexported fields
}
func NewCSVNode ¶
func NewCSVNode( root *Node, parent *Node, headLocal string, headFull string, tail interface{}, ) Node
NewCSVNode returns instance of preconfigured CSV Node. It contains the information needed to generate a header for data in corresponding CSV field.
func NewCSVRoot ¶
func NewCSVRoot(
tail interface{},
) Node
NewCSVRoot returns instance of preconfigured CSV Node. The returned node is a root of the graph.
func (*Node) ExpandTail ¶
ExpandTail retrieves the values of all tails in the graph and creates the whole graph structure.
func (*Node) GetHeaders ¶
GetHeaders returns an array of headers of all child nodes.
Click to show internal directories.
Click to hide internal directories.